Changelog
---------

0.6.2 (2018-02-08)
~~~~~~~~~~~~~~~~~~~

- Ensures that incorrect coordinates cannot be submitted in forms.
  [href]

0.6.1 (2018-02-06)
~~~~~~~~~~~~~~~~~~~

- Fixes javascript error occurring on empty maps.
  [href]

0.6.0 (2017-12-29)
~~~~~~~~~~~~~~~~~~~

- Requires Python 3.6.
  [href]

- Adds a display renderer for the coordinates field.
  [href]

- Automatically turns the corodinates model into a json and vice-versa.
  [href]

0.5.2 (2017-12-22)
~~~~~~~~~~~~~~~~~~~

- Switches to onegov core's custom json module.
  [href]

- Renders icon in marker as svg, not html.
  [href]

0.5.1 (2017-11-29)
~~~~~~~~~~~~~~~~~~~

- Improves drawing performance of map markers.
  [href]

0.5.0 (2017-11-07)
~~~~~~~~~~~~~~~~~~~

- Upgrades to leaflet 1.2.0.
  [href]

- Adds a reference to each created map to the document.
  [href]

- Adds a gejson map type.
  [href]

0.4.4 (2017-10-17)
~~~~~~~~~~~~~~~~~~~

- Fixes empty coordinates resulting in an error.
  [href]

0.4.3 (2017-10-12)
~~~~~~~~~~~~~~~~~~~

- Improves style of map buttons and provides more space for gecode results.
  [href]

0.4.2 (2017-09-01)
~~~~~~~~~~~~~~~~~~~

- Accepts more values on the coordinates ORM field.
  [href]

0.4.1 (2017-09-01)
~~~~~~~~~~~~~~~~~~~

- Accepts more values on the coordinates setter.
  [href]

0.4.0 (2017-07-12)
~~~~~~~~~~~~~~~~~~~

- Upgrade Leaflet and its plugins to the latest release.
  [href]

0.3.3 (2017-02-15)
~~~~~~~~~~~~~~~~~~~

- Decreases the likelihood of scrolling triggering a zoom on a map.
  [href]

0.3.2 (2016-04-11)
~~~~~~~~~~~~~~~~~~~

- Fixes a display issue on IE.
  [href]

0.3.1 (2016-04-11)
~~~~~~~~~~~~~~~~~~~

- Adds a simple geocoding button to the leaflet map.
  [href]

0.3.0 (2016-04-08)
~~~~~~~~~~~~~~~~~~~

- Moves to new more.webassets.
  [href]

0.2.1 (2016-04-06)
~~~~~~~~~~~~~~~~~~~

- Adds compatibility with Morepath 0.13.
  [href]

0.2.0 (2016-04-05)
~~~~~~~~~~~~~~~~~~~

- Changes the mouse pointer to default on unclickable markers.
  [href]

- Fixes form submit not working with enter key in map enabled forms.
  [href]

- Acquires the default view parameters from the body.
  [href]

0.1.0 (2016-04-05)
~~~~~~~~~~~~~~~~~~~

- Adds the ability to display a (readonly) map with a marker.
  [href]

0.0.1 (2016-04-01)
~~~~~~~~~~~~~~~~~~~

- Initial Release
